pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list_by_database(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn list_by_database( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
List database schemas
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn get(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
schema_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, schema_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Get database schema
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.schema_name: The name of the schema.subscription_id: The subscription ID that identifies an Azure subscription.