DatabaseUpdateProperties

Struct DatabaseUpdateProperties 

pub struct DatabaseUpdateProperties {
Show 46 fields pub create_mode: Option<CreateMode>, pub collation: Option<String>, pub max_size_bytes: Option<i64>, pub sample_name: Option<SampleName>, pub elastic_pool_id: Option<String>, pub source_database_id: Option<String>, pub status: Option<Status>, pub database_id: Option<String>, pub creation_date: Option<OffsetDateTime>, pub current_service_objective_name: Option<String>, pub requested_service_objective_name: Option<String>, pub default_secondary_location: Option<String>, pub failover_group_id: Option<String>, pub restore_point_in_time: Option<OffsetDateTime>, pub source_database_deletion_date: Option<OffsetDateTime>, pub recovery_services_recovery_point_id: Option<String>, pub long_term_retention_backup_resource_id: Option<String>, pub recoverable_database_id: Option<String>, pub restorable_dropped_database_id: Option<String>, pub catalog_collation: Option<CatalogCollation>, pub zone_redundant: Option<bool>, pub license_type: Option<LicenseType>, pub max_log_size_bytes: Option<i64>, pub earliest_restore_date: Option<OffsetDateTime>, pub read_scale: Option<ReadScale>, pub high_availability_replica_count: Option<i32>, pub secondary_type: Option<SecondaryType>, pub current_sku: Option<Sku>, pub auto_pause_delay: Option<i32>, pub current_backup_storage_redundancy: Option<CurrentBackupStorageRedundancy>, pub requested_backup_storage_redundancy: Option<RequestedBackupStorageRedundancy>, pub min_capacity: Option<f64>, pub paused_date: Option<OffsetDateTime>, pub resumed_date: Option<OffsetDateTime>, pub maintenance_configuration_id: Option<String>, pub is_ledger_on: Option<bool>, pub is_infra_encryption_enabled: Option<bool>, pub federated_client_id: Option<String>, pub keys: Option<Value>, pub encryption_protector: Option<String>, pub preferred_enclave_type: Option<PreferredEnclaveType>, pub use_free_limit: Option<bool>, pub free_limit_exhaustion_behavior: Option<FreeLimitExhaustionBehavior>, pub manual_cutover: Option<bool>, pub perform_cutover: Option<bool>, pub encryption_protector_auto_rotation: Option<bool>,
}
A database update properties.

Fields

create_mode: Option<CreateMode>

Specifies the mode of database creation.

Default: regular database creation.

Copy: creates a database as a copy of an existing database. sourceDatabaseId must be specified as the resource ID of the source database.

Secondary: creates a database as a secondary replica of an existing database. sourceDatabaseId must be specified as the resource ID of the existing primary database.

PointInTimeRestore: Creates a database by restoring a point in time backup of an existing database. sourceDatabaseId must be specified as the resource ID of the existing database, and restorePointInTime must be specified.

Recovery: Creates a database by restoring a geo-replicated backup. sourceDatabaseId must be specified as the recoverable database resource ID to restore.

Restore: Creates a database by restoring a backup of a deleted database. sourceDatabaseId must be specified. If sourceDatabaseId is the database’s original resource ID, then sourceDatabaseDeletionDate must be specified. Otherwise sourceDatabaseId must be the restorable dropped database resource ID and sourceDatabaseDeletionDate is ignored. restorePointInTime may also be specified to restore from an earlier point in time.

RestoreLongTermRetentionBackup: Creates a database by restoring from a long term retention vault. recoveryServicesRecoveryPointResourceId must be specified as the recovery point resource ID.

Copy, Secondary, and RestoreLongTermRetentionBackup are not supported for DataWarehouse edition.

collation: Option<String>

The collation of the database.

max_size_bytes: Option<i64>

The max size of the database expressed in bytes.

sample_name: Option<SampleName>

The name of the sample schema to apply when creating this database.

elastic_pool_id: Option<String>

The resource identifier of the elastic pool containing this database.

source_database_id: Option<String>

The resource identifier of the source database associated with create operation of this database.

status: Option<Status>

The status of the database.

database_id: Option<String>

The ID of the database.

creation_date: Option<OffsetDateTime>

The creation date of the database (ISO8601 format).

current_service_objective_name: Option<String>

The current service level objective name of the database.

requested_service_objective_name: Option<String>

The requested service level objective name of the database.

default_secondary_location: Option<String>

The default secondary region for this database.

failover_group_id: Option<String>

Failover Group resource identifier that this database belongs to.

restore_point_in_time: Option<OffsetDateTime>

Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database.

source_database_deletion_date: Option<OffsetDateTime>

Specifies the time that the database was deleted.

recovery_services_recovery_point_id: Option<String>

The resource identifier of the recovery point associated with create operation of this database.

long_term_retention_backup_resource_id: Option<String>

The resource identifier of the long term retention backup associated with create operation of this database.

recoverable_database_id: Option<String>

The resource identifier of the recoverable database associated with create operation of this database.

restorable_dropped_database_id: Option<String>

The resource identifier of the restorable dropped database associated with create operation of this database.

catalog_collation: Option<CatalogCollation>

Collation of the metadata catalog.

zone_redundant: Option<bool>

Whether or not this database is zone redundant, which means the replicas of this database will be spread across multiple availability zones.

license_type: Option<LicenseType>

The license type to apply for this database. LicenseIncluded if you need a license, or BasePrice if you have a license and are eligible for the Azure Hybrid Benefit.

max_log_size_bytes: Option<i64>

The max log size for this database.

earliest_restore_date: Option<OffsetDateTime>

This records the earliest start date and time that restore is available for this database (ISO8601 format).

read_scale: Option<ReadScale>

The state of read-only routing. If enabled, connections that have application intent set to readonly in their connection string may be routed to a readonly secondary replica in the same region. Not applicable to a Hyperscale database within an elastic pool.

high_availability_replica_count: Option<i32>

The number of secondary replicas associated with the Business Critical, Premium, or Hyperscale edition database that are used to provide high availability. Not applicable to a Hyperscale database within an elastic pool.

secondary_type: Option<SecondaryType>

The secondary type of the database if it is a secondary. Valid values are Geo, Named and Standby.

current_sku: Option<Sku>

An ARM Resource SKU.

auto_pause_delay: Option<i32>

Time in minutes after which database is automatically paused. A value of -1 means that automatic pause is disabled

current_backup_storage_redundancy: Option<CurrentBackupStorageRedundancy>

The storage account type used to store backups for this database.

requested_backup_storage_redundancy: Option<RequestedBackupStorageRedundancy>

The storage account type to be used to store backups for this database.

min_capacity: Option<f64>

Minimal capacity that database will always have allocated, if not paused

paused_date: Option<OffsetDateTime>

The date when database was paused by user configuration or action(ISO8601 format). Null if the database is ready.

resumed_date: Option<OffsetDateTime>

The date when database was resumed by user action or database login (ISO8601 format). Null if the database is paused.

maintenance_configuration_id: Option<String>

Maintenance configuration id assigned to the database. This configuration defines the period when the maintenance updates will occur.

is_ledger_on: Option<bool>

Whether or not this database is a ledger database, which means all tables in the database are ledger tables. Note: the value of this property cannot be changed after the database has been created.

is_infra_encryption_enabled: Option<bool>

Infra encryption is enabled for this database.

federated_client_id: Option<String>

The Client id used for cross tenant per database CMK scenario

keys: Option<Value>

The resource ids of the user assigned identities to use

encryption_protector: Option<String>

The azure key vault URI of the database if it’s configured with per Database Customer Managed Keys.

preferred_enclave_type: Option<PreferredEnclaveType>

Type of enclave requested on the database i.e. Default or VBS enclaves.

use_free_limit: Option<bool>

Whether or not the database uses free monthly limits. Allowed on one database in a subscription.

free_limit_exhaustion_behavior: Option<FreeLimitExhaustionBehavior>

Specifies the behavior when monthly free limits are exhausted for the free database.

AutoPause: The database will be auto paused upon exhaustion of free limits for remainder of the month.

BillForUsage: The database will continue to be online upon exhaustion of free limits and any overage will be billed.

manual_cutover: Option<bool>

Whether or not customer controlled manual cutover needs to be done during Update Database operation to Hyperscale tier.

This property is only applicable when scaling database from Business Critical/General Purpose/Premium/Standard tier to Hyperscale tier.

When manualCutover is specified, the scaling operation will wait for user input to trigger cutover to Hyperscale database.

To trigger cutover, please provide ‘performCutover’ parameter when the Scaling operation is in Waiting state.

perform_cutover: Option<bool>

To trigger customer controlled manual cutover during the wait state while Scaling operation is in progress.

This property parameter is only applicable for scaling operations that are initiated along with ‘manualCutover’ parameter.

This property is only applicable when scaling database from Business Critical/General Purpose/Premium/Standard tier to Hyperscale tier is already in progress.

When performCutover is specified, the scaling operation will trigger cutover and perform role-change to Hyperscale database.

encryption_protector_auto_rotation: Option<bool>

The flag to enable or disable auto rotation of database encryption protector AKV key.

Implementations