pub struct ManagedInstanceProperties {Show 41 fields
pub provisioning_state: Option<ProvisioningState>,
pub managed_instance_create_mode: Option<ManagedInstanceCreateMode>,
pub fully_qualified_domain_name: Option<String>,
pub is_general_purpose_v2: Option<bool>,
pub administrator_login: Option<String>,
pub administrator_login_password: Option<String>,
pub subnet_id: Option<String>,
pub state: Option<String>,
pub license_type: Option<LicenseType>,
pub hybrid_secondary_usage: Option<HybridSecondaryUsage>,
pub hybrid_secondary_usage_detected: Option<HybridSecondaryUsageDetected>,
pub v_cores: Option<i32>,
pub storage_size_in_gb: Option<i32>,
pub storage_i_ops: Option<i32>,
pub storage_throughput_m_bps: Option<i32>,
pub total_memory_mb: Option<i32>,
pub collation: Option<String>,
pub dns_zone: Option<String>,
pub dns_zone_partner: Option<String>,
pub public_data_endpoint_enabled: Option<bool>,
pub source_managed_instance_id: Option<String>,
pub restore_point_in_time: Option<OffsetDateTime>,
pub proxy_override: Option<ProxyOverride>,
pub timezone_id: Option<String>,
pub instance_pool_id: Option<String>,
pub maintenance_configuration_id: Option<String>,
pub private_endpoint_connections: Vec<ManagedInstancePecProperty>,
pub minimal_tls_version: Option<String>,
pub current_backup_storage_redundancy: Option<CurrentBackupStorageRedundancy>,
pub requested_backup_storage_redundancy: Option<RequestedBackupStorageRedundancy>,
pub zone_redundant: Option<bool>,
pub primary_user_assigned_identity_id: Option<String>,
pub key_id: Option<String>,
pub administrators: Option<ManagedInstanceExternalAdministrator>,
pub service_principal: Option<ServicePrincipal>,
pub virtual_cluster_id: Option<String>,
pub external_governance_status: Option<ExternalGovernanceStatus>,
pub pricing_model: Option<PricingModel>,
pub create_time: Option<OffsetDateTime>,
pub authentication_metadata: Option<AuthenticationMetadata>,
pub database_format: Option<DatabaseFormat>,
}Expand description
The properties of a managed instance.
Fields
provisioning_state: Option<ProvisioningState>Provisioning state of managed instance.
managed_instance_create_mode: Option<ManagedInstanceCreateMode>Specifies the mode of database creation.
Default: Regular instance creation.
Restore: Creates an instance by restoring a set of backups to specific point in time. RestorePointInTime and SourceManagedInstanceId must be specified.
fully_qualified_domain_name: Option<String>The fully qualified domain name of the managed instance.
is_general_purpose_v2: Option<bool>Whether or not this is a GPv2 variant of General Purpose edition.
administrator_login: Option<String>Administrator username for the managed instance. Can only be specified when the managed instance is being created (and is required for creation).
administrator_login_password: Option<String>The administrator login password (required for managed instance creation).
subnet_id: Option<String>Subnet resource ID for the managed instance.
state: Option<String>The state of the managed instance.
license_type: Option<LicenseType>The license type. Possible values are ‘LicenseIncluded’ (regular price inclusive of a new SQL license) and ‘BasePrice’ (discounted AHB price for bringing your own SQL licenses).
hybrid_secondary_usage: Option<HybridSecondaryUsage>Hybrid secondary usage. Possible values are ‘Active’ (default value) and ‘Passive’ (customer uses the secondary as Passive DR).
hybrid_secondary_usage_detected: Option<HybridSecondaryUsageDetected>Hybrid secondary usage detected. Possible values are ‘Active’ (customer does not meet the requirements to use the secondary as Passive DR) and ‘Passive’ (customer meets the requirements to use the secondary as Passive DR).
v_cores: Option<i32>The number of vCores. Allowed values: 8, 16, 24, 32, 40, 64, 80.
storage_size_in_gb: Option<i32>Storage size in GB. Minimum value: 32. Maximum value: 16384. Increments of 32 GB allowed only. Maximum value depends on the selected hardware family and number of vCores.
storage_i_ops: Option<i32>Storage IOps. Minimum value: 300. Maximum value: 80000. Increments of 1 IOps allowed only. Maximum value depends on the selected hardware family and number of vCores.
storage_throughput_m_bps: Option<i32>Storage throughput MBps parameter is not supported in the instance create/update operation.
total_memory_mb: Option<i32>Total memory in MB. Minimum value: 7168. Maximum value: 891328. Increments of 1 MB allowed only. Maximum value depends on the selected hardware family and number of vCores.
collation: Option<String>Collation of the managed instance.
dns_zone: Option<String>The Dns Zone that the managed instance is in.
dns_zone_partner: Option<String>The resource id of another managed instance whose DNS zone this managed instance will share after creation.
public_data_endpoint_enabled: Option<bool>Whether or not the public data endpoint is enabled.
source_managed_instance_id: Option<String>The resource identifier of the source managed instance associated with create operation of this instance.
restore_point_in_time: Option<OffsetDateTime>Specifies the point in time (ISO8601 format) of the source database that will be restored to create the new database.
proxy_override: Option<ProxyOverride>Connection type used for connecting to the instance.
timezone_id: Option<String>Id of the timezone. Allowed values are timezones supported by Windows. Windows keeps details on supported timezones, including the id, in registry under KEY_LOCAL_MACHINE\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Time Zones. You can get those registry values via SQL Server by querying SELECT name AS timezone_id FROM sys.time_zone_info. List of Ids can also be obtained by executing [System.TimeZoneInfo]::GetSystemTimeZones() in PowerShell. An example of valid timezone id is “Pacific Standard Time” or “W. Europe Standard Time”.
instance_pool_id: Option<String>The Id of the instance pool this managed server belongs to.
maintenance_configuration_id: Option<String>Specifies maintenance configuration id to apply to this managed instance.
private_endpoint_connections: Vec<ManagedInstancePecProperty>List of private endpoint connections on a managed instance.
minimal_tls_version: Option<String>Minimal TLS version. Allowed values: ‘None’, ‘1.0’, ‘1.1’, ‘1.2’
current_backup_storage_redundancy: Option<CurrentBackupStorageRedundancy>The storage account type used to store backups for this instance. The options are Local (LocallyRedundantStorage), Zone (ZoneRedundantStorage), Geo (GeoRedundantStorage) and GeoZone(GeoZoneRedundantStorage)
requested_backup_storage_redundancy: Option<RequestedBackupStorageRedundancy>The storage account type to be used to store backups for this instance. The options are Local (LocallyRedundantStorage), Zone (ZoneRedundantStorage), Geo (GeoRedundantStorage) and GeoZone(GeoZoneRedundantStorage)
zone_redundant: Option<bool>Whether or not the multi-az is enabled.
primary_user_assigned_identity_id: Option<String>The resource id of a user assigned identity to be used by default.
key_id: Option<String>A CMK URI of the key to use for encryption.
administrators: Option<ManagedInstanceExternalAdministrator>Properties of a active directory administrator.
service_principal: Option<ServicePrincipal>The managed instance’s service principal configuration for a resource.
virtual_cluster_id: Option<String>Virtual cluster resource id for the Managed Instance.
external_governance_status: Option<ExternalGovernanceStatus>Status of external governance.
pricing_model: Option<PricingModel>Pricing model of Managed Instance.
create_time: Option<OffsetDateTime>Specifies the point in time (ISO8601 format) of the Managed Instance creation.
authentication_metadata: Option<AuthenticationMetadata>The managed instance’s authentication metadata lookup mode.
database_format: Option<DatabaseFormat>Specifies the internal format of instance databases specific to the SQL engine version.
Implementations