pub struct ResourceIdentity {
pub user_assigned_identities: Option<Value>,
pub principal_id: Option<String>,
pub type_: Option<Type>,
pub tenant_id: Option<String>,
}Expand description
Azure Active Directory identity configuration for a resource.
Fields
user_assigned_identities: Option<Value>The resource ids of the user assigned identities to use
principal_id: Option<String>The Azure Active Directory principal id.
type_: Option<Type>The identity type. Set this to ‘SystemAssigned’ in order to automatically create and assign an Azure Active Directory principal for the resource.
tenant_id: Option<String>The Azure Active Directory tenant id.
Implementations