pub struct SecurityAlertPolicyProperties {
pub state: State,
pub disabled_alerts: Vec<String>,
pub email_addresses: Vec<String>,
pub email_account_admins: Option<bool>,
pub storage_endpoint: Option<String>,
pub storage_account_access_key: Option<String>,
pub retention_days: Option<i32>,
pub creation_time: Option<OffsetDateTime>,
}Expand description
Properties of a security alert policy.
Fields
state: StateSpecifies the state of the policy, whether it is enabled or disabled or a policy has not been applied yet on the specific database.
disabled_alerts: Vec<String>Specifies an array of alerts that are disabled. Allowed values are: Sql_Injection, Sql_Injection_Vulnerability, Access_Anomaly, Data_Exfiltration, Unsafe_Action, Brute_Force
email_addresses: Vec<String>Specifies an array of e-mail addresses to which the alert is sent.
email_account_admins: Option<bool>Specifies that the alert is sent to the account administrators.
storage_endpoint: Option<String>Specifies the blob storage endpoint (e.g. https://MyAccount.blob.core.windows.net). This blob storage will hold all Threat Detection audit logs.
storage_account_access_key: Option<String>Specifies the identifier key of the Threat Detection audit storage account.
retention_days: Option<i32>Specifies the number of days to keep in the Threat Detection audit logs.
creation_time: Option<OffsetDateTime>Specifies the UTC creation time of the policy.
Implementations