pub struct ServerVulnerabilityAssessmentProperties {
pub storage_container_path: String,
pub storage_container_sas_key: Option<String>,
pub storage_account_access_key: Option<String>,
pub recurring_scans: Option<VulnerabilityAssessmentRecurringScansProperties>,
}Expand description
Properties of a server Vulnerability Assessment.
Fields
storage_container_path: StringA blob storage container path to hold the scan results (e.g. https://myStorage.blob.core.windows.net/VaScans/).
storage_container_sas_key: Option<String>A shared access signature (SAS Key) that has write access to the blob container specified in ‘storageContainerPath’ parameter. If ‘storageAccountAccessKey’ isn’t specified, StorageContainerSasKey is required. Applies only if the storage account is not behind a Vnet or a firewall
storage_account_access_key: Option<String>Specifies the identifier key of the storage account for vulnerability assessment scan results. If ‘StorageContainerSasKey’ isn’t specified, storageAccountAccessKey is required. Applies only if the storage account is not behind a Vnet or a firewall
recurring_scans: Option<VulnerabilityAssessmentRecurringScansProperties>Properties of a Vulnerability Assessment recurring scans.
Implementations