pub struct SyncGroupProperties {
pub interval: Option<i32>,
pub last_sync_time: Option<OffsetDateTime>,
pub conflict_resolution_policy: Option<ConflictResolutionPolicy>,
pub sync_database_id: Option<String>,
pub hub_database_user_name: Option<String>,
pub hub_database_password: Option<String>,
pub sync_state: Option<SyncState>,
pub schema: Option<SyncGroupSchema>,
pub enable_conflict_logging: Option<bool>,
pub conflict_logging_retention_in_days: Option<i32>,
pub use_private_link_connection: Option<bool>,
pub private_endpoint_name: Option<String>,
}Expand description
Properties of a sync group.
Fields
interval: Option<i32>Sync interval of the sync group.
last_sync_time: Option<OffsetDateTime>Last sync time of the sync group.
conflict_resolution_policy: Option<ConflictResolutionPolicy>Conflict resolution policy of the sync group.
sync_database_id: Option<String>ARM resource id of the sync database in the sync group.
hub_database_user_name: Option<String>User name for the sync group hub database credential.
hub_database_password: Option<String>Password for the sync group hub database credential.
sync_state: Option<SyncState>Sync state of the sync group.
schema: Option<SyncGroupSchema>Properties of sync group schema.
enable_conflict_logging: Option<bool>If conflict logging is enabled.
conflict_logging_retention_in_days: Option<i32>Conflict logging retention period.
use_private_link_connection: Option<bool>If use private link connection is enabled.
private_endpoint_name: Option<String>Private endpoint name of the sync group if use private link connection is enabled.
Implementations