pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list_by_database(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn list_by_database( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Gets a list of replication links on database.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn get(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
link_id: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, link_id: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Gets a replication link.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.link_id: The name of the replication link.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn create_or_update(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
link_id: impl Into<String>,
parameters: impl Into<ReplicationLink>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn create_or_update( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, link_id: impl Into<String>, parameters: impl Into<ReplicationLink>, subscription_id: impl Into<String>, ) -> RequestBuilder
Updates the replication link type.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn update(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
link_id: impl Into<String>,
parameters: impl Into<ReplicationLinkUpdate>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn update( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, link_id: impl Into<String>, parameters: impl Into<ReplicationLinkUpdate>, subscription_id: impl Into<String>, ) -> RequestBuilder
Updates the replication link type.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn delete(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
link_id: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn delete( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, link_id: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Deletes the replication link.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn failover(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
link_id: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn failover( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, link_id: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Fails over from the current primary server to this server.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.link_id: The name of the replication link.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn failover_allow_data_loss(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
database_name: impl Into<String>,
link_id: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn failover_allow_data_loss( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, database_name: impl Into<String>, link_id: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Fails over from the current primary server to this server allowing data loss.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.database_name: The name of the database.link_id: The name of the replication link.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn list_by_server(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn list_by_server( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Gets a list of replication links.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.subscription_id: The subscription ID that identifies an Azure subscription.