pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn check_name_availability(
&self,
parameters: impl Into<CheckNameAvailabilityRequest>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn check_name_availability( &self, parameters: impl Into<CheckNameAvailabilityRequest>, subscription_id: impl Into<String>, ) -> RequestBuilder
Determines whether a resource can be created with the specified name.
Arguments:
parameters: The name availability request parameters.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn list(&self, subscription_id: impl Into<String>) -> RequestBuilder
pub fn list(&self, subscription_id: impl Into<String>) -> RequestBuilder
Gets a list of all servers in the subscription.
Arguments:
subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn list_by_resource_group(
&self,
resource_group_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn list_by_resource_group( &self, resource_group_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Gets a list of servers in a resource groups.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn get(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Gets a server.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn create_or_update(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
parameters: impl Into<Server>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn create_or_update( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, parameters: impl Into<Server>, subscription_id: impl Into<String>, ) -> RequestBuilder
Creates or updates a server.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.parameters: The requested server resource state.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn update(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
parameters: impl Into<ServerUpdate>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn update( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, parameters: impl Into<ServerUpdate>, subscription_id: impl Into<String>, ) -> RequestBuilder
Updates a server.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.parameters: The requested server resource state.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn delete(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn delete( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Deletes a server.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn import_database(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
parameters: impl Into<ImportNewDatabaseDefinition>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn import_database( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, parameters: impl Into<ImportNewDatabaseDefinition>, subscription_id: impl Into<String>, ) -> RequestBuilder
Imports a bacpac into a new database.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.parameters: The database import request parameters.subscription_id: The subscription ID that identifies an Azure subscription.
Sourcepub fn refresh_status(
&self,
resource_group_name: impl Into<String>,
server_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn refresh_status( &self, resource_group_name: impl Into<String>, server_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Refresh external governance enablement status.
Arguments:
resource_group_name: The name of the resource group that contains the resource. You can obtain this value from the Azure Resource Manager API or the portal.server_name: The name of the server.subscription_id: The subscription ID that identifies an Azure subscription.